==> dl.php?src=linea21_1_8.zip: linea21/languages/en/lang_publication.utf-8.php <==
<?php
/**
 * @package linea21\languages\en
 * @author $Author$ - linea21 <info@linea21.com> & Stéphanie Loubechine
 * @version $Id$ 
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */


$lang['publication']['section'] = "publications";

/*	nommage des modules
 *  	*/
$lang['publication']['name']='publication';
$lang['publication']['name2']='publication(s)';
$lang['publication']['confirm_add'] = "publication successfully added\n";
$lang['publication']['confirm_mod'] = "publication successfully updated\n";
$lang['publication']['confirm_sup'] ="publication successfully deleted\n";


/*	nommage rubrique module
 *  	*/
$lang['publication']['add']= 'Add a new '.$lang['publication']['name'];
$lang['publication']['mod']= 'Edit '.$lang['publication']['name'];
$lang['publication']['sup']= 'Delete '.$lang['publication']['name'];
$lang['publication']['det']= ucfirst($lang['publication']['name']) . ' details';
$lang['publication']['list']= 'View publications';


/*	nommage public
 *  	*/
$lang['publication']['next_part']='Next part ';
$lang['publication']['prev_part']='Previous part ';
$lang['publication']['goto']='Go to ';
/*	nommage rubrique add / mod /det
 *  	*/
$lang['publication']['add_title']='Add data about the new '.$lang['publication']['name'];
$lang['publication']['mod_title']='Edit data about '.$lang['publication']['name'];

$lang['publication']['h1_public_comment']='Reading our publications, you will find all informations and materials to understand better what we do.';

/*	check integrité des données
 *  	*/
$lang['publication']['no_title'] = 'Title is required';
$lang['publication']['no_resume'] = 'Body is required';
$lang['publication']['no_theme'] = 'Theme is required';
$lang['publication']['no_scale'] = 'Scale is required';
$lang['publication']['no_author'] = 'Author is required';
$lang['publication']['author_not_valid'] = 'The given author is not a valid author';
$lang['publication']['author_not_rights'] = 'The given author does not have the required rights level';

/*	nommage élément rubrique
 *  	*/
$lang['publication']['title']='title';
$lang['publication']['resume']='body';
$lang['publication']['theme']='asociated theme';
$lang['publication']['scale']='asociated scale';
$lang['publication']['statut']='status';
$lang['publication']['comment']='comment';

$lang['publication']['template']='template';
$lang['publication']['photouri']='associated picture(s)';
$lang['publication']['visu1']='associated picture n°1';
$lang['publication']['visu2']='associated picture n°2';
$lang['publication']['author']='author';
$lang['publication']['published_on']='published on';
$lang['publication']['not_published']='not published';

$lang['publication']['generals']='Global informations';
$lang['publication']['parts']='Publication details';
$lang['publication']['listing']='Publications';
$lang['publication']['link_res']='Associated links';
$lang['publication']['biblio_res']='Bibliographical resources';
$lang['publication']['multi_res']='Multimedia resources';
$lang['publication']['summary']='Summary';



/*	nommage quickbox
 *  	*/
$lang['publication']['qb_titleadd']=' latest additions';
$lang['publication']['qb_titlemod']=' latest modifications';
$lang['publication']['qb_titlesup']=' latest deletions';
$lang['publication']['qb_titlepubli']=' latest publications';


/*	divers
 *  	*/

$lang['publication']['nb_total']='publications in database.';
$lang['publication']['statut_filter']='Display by status';
$lang['publication']['part_number']='part ';
$lang['publication']['part_number2']='Part ';
$lang['publication']['description']='description';
$lang['publication']['all']='Dsiplay full list';
$lang['publication']['noresult']='There is no publication with this criteria ';
$lang['news']['template_1']='Text + photo on the left';
$lang['news']['template_2']='Text + photo on the right';
$lang['news']['template_3']='Text only';


/*	textes modules annexes
 *  	*/
$lang['publication']['add_new_part']="Add a new part to this publication";
$lang['publication']['add_new_linkres']="Add a new link to this publication";
$lang['publication']['add_new_multires']="Add a new media reference to this publication";
$lang['publication']['add_new_bibliores']="Add a new bibliographical notice to this publication";

$lang['publication']['no_link']="There is no link to this publication";
$lang['publication']['del_link']="Delete link";
$lang['publication']['mod_link']="Edit link";

$lang['publication']['no_multi']="There is no media reference associated with this publication";
$lang['publication']['del_multi']="Delete media reference";
$lang['publication']['mod_multi']="Edit media reference";

$lang['publication']['no_biblio']="There is no bibliographical notice associated with this publication";
$lang['publication']['del_biblio']="Delete bibliographical notice";
$lang['publication']['mod_biblio']="Update bibliographical notice";

$lang['publication']['no_part']="There is no part to this publication";
$lang['publication']['del_part']="Delete part";
$lang['publication']['mod_part']="Update part";






/*	rubrique d'aide

*  	*/
$lang['publication']['help_add1']='To add a publication, please insert the required informations in the form above';
$lang['publication']['help_add2']='After submitting the form, check your data in the summary';
$lang['publication']['help_add3']='After checking summary, click the \'review settings\' button to make changes';

$lang['publication']['help_list1']='Click on publication title to display more information';
$lang['publication']['help_list2']='Delete publication by clicking on the delete icon linked in';
$lang['publication']['help_list3']='Edit publication by clicking on the edit icon linked in';
$lang['publication']['help_list4']='Filter by status to display publications for a given status';
$lang['publication']['help_list5']='To add a publication, please insert the required informations in the form above';


$lang['publication']['help_mod1']='To add a publication, please insert the required informations in the form above';
$lang['publication']['help_mod2']='Once the form submitted, check your data in the summary';
$lang['publication']['help_mod3']='Once the summary displayed, click the \'review settings\' button if you need to make new changes';


$lang['publication']['help_det1']='Edit publication by clicking on the edit icon linked in';
$lang['publication']['help_det2']='Delete publication by clicking on the delete icon linked in';
$lang['publication']['help_det3']='To display publications parts, links, medias and bibliographical notices, click on more informations';
$lang['publication']['help_det4']='To Add-Edit-Delete publications parts, links, medias and bibliographical notices, click on the icons linked in';

$lang['publication']['help_sup1']='Click cancel to abort deletion';


?>

==> dl.php?src=linea21_2_3_0.zip: linea21/languages/en/lang_publication.utf-8.php <==
<?php
/**
 * @package linea21\languages\en
 * @author $Author$ - linea21 <info@linea21.com> & Stéphanie Loubechine
 * @version $Id$ 
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */


$lang['publication']['section'] = "publications";

/*	nommage des modules
 *  	*/
$lang['publication']['name']='publication';
$lang['publication']['name2']='publication(s)';
$lang['publication']['confirm_add'] = "publication successfully added\n";
$lang['publication']['confirm_mod'] = "publication successfully updated\n";
$lang['publication']['confirm_sup'] ="publication successfully deleted\n";


/*	nommage rubrique module
 *  	*/
$lang['publication']['add']= 'Add a new '.$lang['publication']['name'];
$lang['publication']['mod']= 'Edit '.$lang['publication']['name'];
$lang['publication']['sup']= 'Delete '.$lang['publication']['name'];
$lang['publication']['det']= ucfirst($lang['publication']['name']) . ' details';
$lang['publication']['list']= 'View publications';


/*	nommage public
 *  	*/
$lang['publication']['next_part']='Next part ';
$lang['publication']['prev_part']='Previous part ';
$lang['publication']['goto']='Go to ';
/*	nommage rubrique add / mod /det
 *  	*/
$lang['publication']['add_title']='Add data about the new '.$lang['publication']['name'];
$lang['publication']['mod_title']='Edit data about '.$lang['publication']['name'];

$lang['publication']['h1_public_comment']='Reading our publications, you will find all informations and materials to understand better what we do.';

/*	check integrité des données
 *  	*/
$lang['publication']['no_title'] = 'Title is required';
$lang['publication']['no_resume'] = 'Body is required';
$lang['publication']['no_level'] = 'Level is required';
$lang['publication']['no_scale'] = 'Scale is required';
$lang['publication']['no_author'] = 'Author is required';
$lang['publication']['author_not_valid'] = 'The given author is not a valid author';
$lang['publication']['author_not_rights'] = 'The given author does not have the required rights level';

/*	nommage élément rubrique
 *  	*/
$lang['publication']['title']='title';
$lang['publication']['resume']='body';
$lang['publication']['level']='asociated level';
$lang['publication']['scale']='asociated scale';
$lang['publication']['statut']='status';
$lang['publication']['comment']='comment';

$lang['publication']['template']='template';
$lang['publication']['photouri']='associated picture(s)';
$lang['publication']['visu1']='associated picture n°1';
$lang['publication']['visu2']='associated picture n°2';
$lang['publication']['author']='author';
$lang['publication']['published_on']='published on';
$lang['publication']['not_published']='not published';

$lang['publication']['generals']='Global informations';
$lang['publication']['parts']='Publication details';
$lang['publication']['listing']='Publications';
$lang['publication']['link_res']='Associated links';
$lang['publication']['biblio_res']='Bibliographical resources';
$lang['publication']['multi_res']='Multimedia resources';
$lang['publication']['summary']='Summary';



/*	nommage quickbox
 *  	*/
$lang['publication']['qb_titleadd']=' latest additions';
$lang['publication']['qb_titlemod']=' latest modifications';
$lang['publication']['qb_titlesup']=' latest deletions';
$lang['publication']['qb_titlepubli']=' latest publications';


/*	divers
 *  	*/

$lang['publication']['nb_total']='publications in database.';
$lang['publication']['statut_filter']='Display by status';
$lang['publication']['part_number']='part ';
$lang['publication']['part_number2']='Part ';
$lang['publication']['description']='description';
$lang['publication']['all']='Dsiplay full list';
$lang['publication']['noresult']='There is no publication with this criteria ';
$lang['news']['template_1']='Text + photo on the left';
$lang['news']['template_2']='Text + photo on the right';
$lang['news']['template_3']='Text only';


/*	textes modules annexes
 *  	*/
$lang['publication']['add_new_part']="Add a new part to this publication";
$lang['publication']['add_new_linkres']="Add a new link to this publication";
$lang['publication']['add_new_multires']="Add a new media reference to this publication";
$lang['publication']['add_new_bibliores']="Add a new bibliographical notice to this publication";

$lang['publication']['no_link']="There is no link to this publication";
$lang['publication']['del_link']="Delete link";
$lang['publication']['mod_link']="Edit link";

$lang['publication']['no_multi']="There is no media reference associated with this publication";
$lang['publication']['del_multi']="Delete media reference";
$lang['publication']['mod_multi']="Edit media reference";

$lang['publication']['no_biblio']="There is no bibliographical notice associated with this publication";
$lang['publication']['del_biblio']="Delete bibliographical notice";
$lang['publication']['mod_biblio']="Update bibliographical notice";

$lang['publication']['no_part']="There is no part to this publication";
$lang['publication']['del_part']="Delete part";
$lang['publication']['mod_part']="Update part";






/*	rubrique d'aide

*  	*/
$lang['publication']['help_add1']='To add a publication, please insert the required informations in the form above';
$lang['publication']['help_add2']='After submitting the form, check your data in the summary';
$lang['publication']['help_add3']='After checking summary, click the \'review settings\' button to make changes';

$lang['publication']['help_list1']='Click on publication title to display more information';
$lang['publication']['help_list2']='Delete publication by clicking on the delete icon linked in';
$lang['publication']['help_list3']='Edit publication by clicking on the edit icon linked in';
$lang['publication']['help_list4']='Filter by status to display publications for a given status';
$lang['publication']['help_list5']='To add a publication, please insert the required informations in the form above';


$lang['publication']['help_mod1']='To add a publication, please insert the required informations in the form above';
$lang['publication']['help_mod2']='Once the form submitted, check your data in the summary';
$lang['publication']['help_mod3']='Once the summary displayed, click the \'review settings\' button if you need to make new changes';


$lang['publication']['help_det1']='Edit publication by clicking on the edit icon linked in';
$lang['publication']['help_det2']='Delete publication by clicking on the delete icon linked in';
$lang['publication']['help_det3']='To display publications parts, links, medias and bibliographical notices, click on more informations';
$lang['publication']['help_det4']='To Add-Edit-Delete publications parts, links, medias and bibliographical notices, click on the icons linked in';

$lang['publication']['help_sup1']='Click cancel to abort deletion';


?>
